#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-FKv2O1GO4Nd9OczNPSMEVw
key:                  lsp-2.2.0.0-FKv2O1GO4Nd9OczNPSMEVw
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  4bcd3c888b3503cac2f5c96e8bc60e9f
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-Dmfs4Cs9wKy6MFfCyo2lvk:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-Dmfs4Cs9wKy6MFfCyo2lvk:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-Dmfs4Cs9wKy6MFfCyo2lvk:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-Dmfs4Cs9wKy6MFfCyo2lvk:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-FKv2O1GO4Nd9OczNPSMEVw
depends:
    aeson-2.2.1.0-2aoKFKPwHseOu8oBERSIn
    async-2.2.5-IaE93ic7JyB4hqU57sYJnB
    attoparsec-0.14.4-CAVADdTBKeoK3WivOosynQ base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-6Mr875MLJi72FoumBVQF00
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-4oPZUh9suePGG68EJUiBDA
    lens-5.3.4-95zsvsVvew2LnSS9OomrvK
    lens-aeson-1.2.3-2ZgixTYDVqQ4z6noozBlLb
    lsp-types-2.0.2.0-Dmfs4Cs9wKy6MFfCyo2lvk mtl-2.3.1
    prettyprinter-1.7.1-S0Vgm51rIvLDdfgcsiFYb
    random-1.2.1.3-FnjU7A0vl9pKTDUEyOHZUN
    row-types-1.0.1.2-2epVvGgfas5JIUdH9qU3xv
    sorted-list-0.2.3.1-Becbw3c6W6yDDHE0OFfeCB stm-2.5.1.0
    temporary-1.3-7AWwGtWBR6G7ykOt23PX0l text-2.0.2
    text-rope-0.3-6gkEOBJIK7lADAB4D37qKh transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-1lWFLFb7qnGGdfGyTf5Bys
    uuid-1.3.16-CQzxGbacRp7KFqewtFFz03

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

